@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 import json
 
-from base import ApolloClientBase
-from util import get_value_from_dict, no_key_cache_key
+from .base import ApolloClientBase
+from .util import get_value_from_dict, no_key_cache_key
 
 
 class ApolloClient(ApolloClientBase):
