@@ -11,9 +11,10 @@ import time
 import traceback
 from urllib.error import HTTPError
 import logging
-from util import *
 import json
 
+from .util import *
+
 
 class ApolloClientBase(object):
 
