@@ -24,7 +24,7 @@ class ApolloClientCase(unittest.TestCase):
         :return:
         """
 
-        from apollo_client import ApolloClient
+        from ..apollo_client import ApolloClient
         logger = cls.get_logger()
         a_client = ApolloClient(
             app_id=APOLLO_APP_ID, secret=APOLLO_ACCESS_KEY_SECRET, config_url=APOLLO_CONFIG_URL, logger=logger
@@ -42,7 +42,7 @@ class ApolloClientCase(unittest.TestCase):
         :return:
         """
 
-        from apollo_client import ApolloClient
+        from ..apollo_client import ApolloClient
         a_client = ApolloClient(
             app_id=APOLLO_APP_ID, secret=APOLLO_ACCESS_KEY_SECRET, config_url=APOLLO_CONFIG_URL
         )
